summaryrefslogtreecommitdiffstats
path: root/src/drivers/nvs/threewire.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/drivers/nvs/threewire.c')
-rw-r--r--src/drivers/nvs/threewire.c5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/drivers/nvs/threewire.c b/src/drivers/nvs/threewire.c
index 552c3b46..043cc8fc 100644
--- a/src/drivers/nvs/threewire.c
+++ b/src/drivers/nvs/threewire.c
@@ -28,14 +28,15 @@
/** Read data from three-wire device
*
* @v device SPI device
* @v address Address from which to read
* @v data Data buffer
* @v len Length of data buffer
* @ret rc Return status code
*/
-int threewire_read ( struct spi_device *device, unsigned int address,
+int threewire_read ( struct nvs_device *nvs, unsigned int address,
void *data, size_t len ) {
+ struct spi_device *device = nvs_to_spi ( nvs );
struct spi_bus *bus = device->bus;
assert ( bus->mode == SPI_MODE_THREEWIRE );
@@ -28,14 +28,15 @@
/** Read data from three-wire device
*
- * @v device SPI device
+ * @v nvs NVS device
* @v address Address from which to read
* @v data Data buffer